@@ -28,9 +28,7 @@ main = do
       intInput = ":123\r\n"
       bulkInput = "$10\r\n0123456789\r\n"
       multiInput = "*3\r\n+A\r\n+B\r\n+C\r\n"
-      binaryInput =
-        let str = ByteString.pack [5, 65, 66, 67, 68, 69]
-        in ByteString.concat (replicate 10 str)
+      binaryInput = ByteString.pack [5, 65, 66, 67, 68, 69]
   print (stringAtto smallStringInput)
   print (stringScanner smallStringInput)
   print (stringWordScanner smallStringInput)
@@ -47,8 +45,6 @@ main = do
   print (redisAttoReply multiInput)
   print (redisZeptoReply multiInput)
   print (redisScannerReply multiInput)
-  print (binaryScanner binaryInput)
-  print (binaryCereal binaryInput)
   defaultMain
     [ bgroup "scanner"
       [ bgroup "string"
@@ -160,45 +156,19 @@ redisByteStringReply bs = case ByteString.uncons bs of
     _ -> Left "Unknown type"
   Nothing -> Left "Not enought input"
 
-binaryScanner :: ByteString -> Either String [ByteString]
-binaryScanner bs = case Scanner.scan p' bs of
+binaryScanner :: ByteString -> Either String ByteString
+binaryScanner bs = case Scanner.scan p bs of
   Scanner.Done _ r -> Right r
   Scanner.Fail _ err -> Left err
   Scanner.More _ -> Left "Not enought input"
   where
-  p' = do
-    a0 <- p
-    a1 <- p
-    a2 <- p
-    a3 <- p
-    a4 <- p
-    a5 <- p
-    a6 <- p
-    a7 <- p
-    a8 <- p
-    a9 <- p
-    return [a0, a1, a2, a3, a4, a5, a6, a7, a8, a9]
-  {-# INLINE p #-}
   p = do
     n <- fromIntegral <$> Scanner.anyWord8
     Scanner.take n
 
-binaryCereal :: ByteString -> Either String [ByteString]
-binaryCereal bs = Cereal.runGet g' bs
+binaryCereal :: ByteString -> Either String ByteString
+binaryCereal bs = Cereal.runGet g bs
   where
-  g' = do
-    a0 <- g
-    a1 <- g
-    a2 <- g
-    a3 <- g
-    a4 <- g
-    a5 <- g
-    a6 <- g
-    a7 <- g
-    a8 <- g
-    a9 <- g
-    return [a0, a1, a2, a3, a4, a5, a6, a7, a8, a9]
-  {-# INLINE g #-}
   g = do
     n <- fromIntegral <$> Cereal.getWord8
     Cereal.getBytes n
